# Kb-handler




```ecmascript 6
    var KbHandler = require('kb-handler')
```

### <a name="signature"></a>Signature

The keyboard handler constructor needs one parameter which will be the event container. Meaning that all events that occur in this context will be catched.
This container needs to have the prototype method `addEventListener` to be working.

Thus all these instanciations are valid:
```javascript
    var kb = new KbHandler(document.body)
    var kb = new KbHandler(document.createComment('event container'))
    var kb = new KbHandler(window)
```


### <a name="kb-handler-instance"></a>Keyboard handler instance

The KbHandler instance exposes a `key` property which contains all keys supported.
This is needed for the `on` function which registers events on the specified key

```javascript
    kb.on(kb.key.Enter)/* conditions and actions then */ 
```

##### <a name="supported-keys"></a> List of supported keys

| Key name          | Keypress support  | Keydown support   | Keyup support     |
|-------------------|:-----------------:|:-----------------:|:-----------------:|
| Escape            | &times;           | &#10004;          | &#10004;          |
| F1                | &times;           | &#10004;          | &#10004;          |
| F2                | &times;           | &#10004;          | &#10004;          |
| F3                | &times;           | &#10004;          | &#10004;          |
| F4                | &times;           | &#10004;          | &#10004;          |
| F5                | &times;           | &#10004;          | &#10004;          |
| F6                | &times;           | &#10004;          | &#10004;          |
| F7                | &times;           | &#10004;          | &#10004;          |
| F8                | &times;           | &#10004;          | &#10004;          |
| F9                | &times;           | &#10004;          | &#10004;          |
| F10               | &times;           | &#10004;          | &#10004;          |
| F11               | &times;           | &#10004;          | &#10004;          |
| F12               | &times;           | &#10004;          | &#10004;          |
| PrintScreen       | &times;           | &times;           | &#10004;          |
| Backquote         | &#10004;          | &#10004;          | &#10004;          |
| Digit0            | &#10004;          | &#10004;          | &#10004;          |
| Digit1            | &#10004;          | &#10004;          | &#10004;          |
| Digit2            | &#10004;          | &#10004;          | &#10004;          |
| Digit3            | &#10004;          | &#10004;          | &#10004;          |
| Digit4            | &#10004;          | &#10004;          | &#10004;          |
| Digit5            | &#10004;          | &#10004;          | &#10004;          |
| Digit6            | &#10004;          | &#10004;          | &#10004;          |
| Digit7            | &#10004;          | &#10004;          | &#10004;          |
| Digit8            | &#10004;          | &#10004;          | &#10004;          |
| Digit9            | &#10004;          | &#10004;          | &#10004;          |
| Backspace         | &times;           | &#10004;          | &#10004;          |
| Space             | &#10004;          | &#10004;          | &#10004;          |
| Enter             | &#10004;          | &#10004;          | &#10004;          |
| Tab               | &times;           | &#10004;          | &times;           |
| CapsLock          | &times;           | &#10004;          | &#10004;          |
| ShiftLeft         | &times;           | &#10004;          | &#10004;          |
| ShiftRight        | &times;           | &#10004;          | &#10004;          |
| ControlLeft       | &times;           | &#10004;          | &#10004;          |
| ControlRight      | &times;           | &#10004;          | &#10004;          |
| MetaLeft          | &times;           | &#10004;          | &#10004;          |
| MetaRight         | &times;           | &#10004;          | &#10004;          |
| AltLeft           | &times;           | &#10004;          | &#10004;          |
| AltRight          | &times;           | &#10004;          | &#10004;          |
| Insert            | &times;           | &#10004;          | &#10004;          |
| Home              | &times;           | &#10004;          | &#10004;          |
| Delete            | &times;           | &#10004;          | &#10004;          |
| End               | &times;           | &#10004;          | &#10004;          |
| PageUp            | &times;           | &#10004;          | &#10004;          |
| PageDown          | &times;           | &#10004;          | &#10004;          |
| ArrowLeft         | &times;           | &#10004;          | &#10004;          |
| ArrowRight        | &times;           | &#10004;          | &#10004;          |
| ArrowUp           | &times;           | &#10004;          | &#10004;          |
| ArrowDown         | &times;           | &#10004;          | &#10004;          |
| NumLock           | &times;           | &times;           | &#10004;          |
| NumpadDivide      | &#10004;          | &#10004;          | &#10004;          |
| NumpadMultiply    | &#10004;          | &#10004;          | &#10004;          |
| NumpadSubstract   | &#10004;          | &#10004;          | &#10004;          |
| NumpadAdd         | &#10004;          | &#10004;          | &#10004;          |
| NumpadEnter       | &#10004;          | &#10004;          | &#10004;          |
| NumpadDecimal     | &#10004;          | &#10004;          | &#10004;          |
| Numpad0           | &#10004;          | &#10004;          | &#10004;          |
| Numpad1           | &#10004;          | &#10004;          | &#10004;          |
| Numpad2           | &#10004;          | &#10004;          | &#10004;          |
| Numpad3           | &#10004;          | &#10004;          | &#10004;          |
| Numpad4           | &#10004;          | &#10004;          | &#10004;          |
| Numpad5           | &#10004;          | &#10004;          | &#10004;          |
| Numpad6           | &#10004;          | &#10004;          | &#10004;          |
| Numpad7           | &#10004;          | &#10004;          | &#10004;          |
| Numpad8           | &#10004;          | &#10004;          | &#10004;          |
| Numpad9           | &#10004;          | &#10004;          | &#10004;          |
| KeyA              | &#10004;          | &#10004;          | &#10004;          |
| KeyB              | &#10004;          | &#10004;          | &#10004;          |
| KeyC              | &#10004;          | &#10004;          | &#10004;          |
| KeyD              | &#10004;          | &#10004;          | &#10004;          |
| KeyE              | &#10004;          | &#10004;          | &#10004;          |
| KeyF              | &#10004;          | &#10004;          | &#10004;          |
| KeyG              | &#10004;          | &#10004;          | &#10004;          |
| KeyH              | &#10004;          | &#10004;          | &#10004;          |
| KeyI              | &#10004;          | &#10004;          | &#10004;          |
| KeyJ              | &#10004;          | &#10004;          | &#10004;          |
| KeyK              | &#10004;          | &#10004;          | &#10004;          |
| KeyL              | &#10004;          | &#10004;          | &#10004;          |
| KeyM              | &#10004;          | &#10004;          | &#10004;          |
| KeyN              | &#10004;          | &#10004;          | &#10004;          |
| KeyO              | &#10004;          | &#10004;          | &#10004;          |
| KeyP              | &#10004;          | &#10004;          | &#10004;          |
| KeyQ              | &#10004;          | &#10004;          | &#10004;          |
| KeyR              | &#10004;          | &#10004;          | &#10004;          |
| KeyS              | &#10004;          | &#10004;          | &#10004;          |
| KeyT              | &#10004;          | &#10004;          | &#10004;          |
| KeyU              | &#10004;          | &#10004;          | &#10004;          |
| KeyV              | &#10004;          | &#10004;          | &#10004;          |
| KeyW              | &#10004;          | &#10004;          | &#10004;          |
| KeyX              | &#10004;          | &#10004;          | &#10004;          |
| KeyY              | &#10004;          | &#10004;          | &#10004;          |
| KeyZ              | &#10004;          | &#10004;          | &#10004;          |
| BracketLeft       | &#10004;          | &#10004;          | &#10004;          |
| BracketRight      | &#10004;          | &#10004;          | &#10004;          |
| Quote             | &#10004;          | &#10004;          | &#10004;          |
| Backslash         | &#10004;          | &#10004;          | &#10004;          |
| Semicolon         | &#10004;          | &#10004;          | &#10004;          |
| Comma             | &#10004;          | &#10004;          | &#10004;          |
| Period            | &#10004;          | &#10004;          | &#10004;          |
| Slash             | &#10004;          | &#10004;          | &#10004;          |
| Any               | &#10004;          | &#10004;          | &#10004;          |


##### <a name="event-methods"></a> Event methods

Once you register an event, some methods become available, providing you control about the event.

Example:
This event will only trigger when the `keyC` will be pressed while holding Control key, will prevent the default
behavior of the original event, will stop its propagation and will call the function `pasteMyContent()` before 
the function `clearMyContentCopied()`.

So this example emulates the true `Ctrl+C` paste command.
```javascript
    kb.on(kb.key.keyC).pressed().withCtrl().prevent().stop().do(pasteMyContent).do(clearMyContentCopied)
```


| Mehod Name    | Parameters    | Description                                                                               |
|---------------|:-------------:|-------------------------------------------------------------------------------------------|
| pressed       | No parameters | The event will only trigger if the origin event is a keyPress                             |
| down          | No parameters | The event will only trigger if the original event is a keyDown                            |
| up            | No parameters | The event will only trigger if the original event is a keyUp                              |
| once          | No parameters | The event will only trigger once                                                          |
| withAlt       | No parameters | The event will only trigger if the alt key is down                                        |
| withCtrl      | No parameters | The event will only trigger if the ctrl key is down                                       |
| withShift     | No parameters | The event will only trigger if the shift key is down                                      |
| withMeta      | No parameters | The event will only trigger if the meta key is down                                       |
| prevent       | No parameters | Prevents the default behavior of the original event                                       |
| stop          | No parameters | Stops the propagation of the original event                                               |
| do            | 0: Function   | Applies a callback to the event (callbacks are called in order which they are assigned    |
